#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadPrompt
version:              1.0.0.5
visibility:           public
id:                   MonadPrompt-1.0.0.5-DtSwz7kv7yR4s21bVJ4wtL
key:                  MonadPrompt-1.0.0.5-DtSwz7kv7yR4s21bVJ4wtL
license:              BSD-3-Clause
copyright:            (c) 2008 Ryan Ingram & Bertram Felgenhauer & Cale Gibbard
maintainer:           ryani.spam@gmail.com
author:               Ryan Ingram
stability:            experimental
synopsis:             MonadPrompt, implementation & examples
description:
    \"Prompting\" monad that allows splitting the description
    of a computation from the implementation of the effects
    used in that computation.
    <http://www.haskell.org/pipermail/haskell-cafe/2008-January/038301.html>

category:             Control
abi:                  8e3d74940e8081b86e44542dc59f5636
exposed:              True
exposed-modules:      Control.Monad.Prompt
import-dirs:          /usr/lib/ghc-8.10.5/site-local/MonadPrompt-1.0.0.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/MonadPrompt-1.0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/MonadPrompt-1.0.0.5
hs-libraries:         HSMonadPrompt-1.0.0.5-DtSwz7kv7yR4s21bVJ4wtL
depends:              base-4.14.2.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-monadprompt/html/MonadPrompt.haddock
haddock-html:         /usr/share/doc/haskell-monadprompt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

